@@ -12,7 +12,7 @@ def all_file(root, patterns='*.pyc', ignore_dirs=[], \
     """
     patterns = tuple([p.strip() for p in patterns.split(',')])
     for path, subdirs, files in os.walk(root):
-        if path.split('/')[-1] in ignore_dirs:
+        if os.path.basename(path) in ignore_dirs:
             continue
         for pattern in patterns:
             fs = fnmatch.filter(files, pattern)
@@ -39,10 +39,9 @@ def clean(args, logger=None, no_matchs=False):
             logger.debug(f)
         else:
             print f
-        continue
         try:
             os.remove(os.path.realpath(f))
-        except:
+        except Exception, e:
             pass
 
 def main():
